import {
  select,
  max,
  csv,
  scaleBand,
  scaleLinear,
  axisLeft,
  axisBottom,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
var margin = {
  left: 80,
  top: 10,
  bottom: 100,
  right: 10,
};

const x = scaleBand().range([
  margin.left,
  width - margin.right - margin.right,
]);
var xAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const y = scaleLinear().range([
  height - margin.bottom,
  margin.top,
]);
var yAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const update = (data) => {
  x.domain(data.map((d) => d.Category));
  xAx
    .call(d3.axisBottom(x))
    .attr('transform', 'translate(0, 410)')
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('dx', '-1em')
    .attr('dy', '-0.5em')
    .attr('transform', 'rotate(-60)');

  y.domain([
    0,
    max(data, (d) => +d['Sales']),
  ]);
  yAx.call(d3.axisLeft(y).tickSize(-width));

  // Rectangles pour le bar plot.
  var u = svg.selectAll('rect').data(data);

  u.enter()
    .append('rect')
    .merge(u)
    .transition()
    .duration(500)  
    .attr('x', (d) => x(d.Category))
    .attr('y', (d) => y(+d['Sales']))
    .attr('width', x.bandwidth())
    .attr(
      'height',
      (d) =>
        height -
        margin.bottom -
        y(d['Sales'])
    );
  	
  	// On doit séparer ici le mouseover à cause de la
    // transition immédiate de la viz.
  	u.on('mouseover', function (d) {
      var x = d3.event.pageX;
      var y = d3.event.pageY;
      d3.select('div.tooltip')
        .style('left', x + 'px')
        .style('top', y + 'px')
        .html(
          'Country: ' +
            d.Country +
            '<br>' +
            'Population: ' +
            d['2022 Population']
        );
    });

  // Circles for the scatter plot.
  var cl = svg.selectAll('circle').data(data);
  cl.enter()
    .append('circle')
    .merge(cl)
    .transition()
    .duration(500)
    .attr('r', '3')
    .style('fill', 'blue')
    .attr('stroke', 'black')
    .attr(
      'cx',
      (d) => x(d.Country) + x.bandwidth() / 2
    )
    .attr('cy', (d) => y(+d['Sales']));
};

csv('data.csv').then((data) => {
  update(data);
/*
  d3.selectAll('.button_click').on(
    'click',
    function () {
      var buttonID = d3.select(this).attr('id');

      if (buttonID == 'asc') {
        update(
          data.sort(function (a, b) {
            return d3['ascending'](
              +a['2022 Population'],
              +b['2022 Population']
            );
          })
        );
      }

      if (buttonID == 'desc') {
        update(
          data.sort(function (a, b) {
            return d3['descending'](
              +a['2022 Population'],
              +b['2022 Population']
            );
          })
        );
      }
    }
  );*/
});